Enum trie_db::TrieError[][src]

pub enum TrieError<T, E> {
    InvalidStateRoot(T),
    IncompleteDatabase(T),
    ValueAtIncompleteKey(Vec<u8>, u8),
    DecoderError(T, E),
    InvalidHash(T, Vec<u8>),
}
Trie Errors.

These borrow the data within them to avoid excessive copying on every trie operation.

Variants

InvalidStateRoot(T)

Attempted to create a trie with a state root not in the DB.

IncompleteDatabase(T)

Trie item not found in the database,

ValueAtIncompleteKey(Vec<u8>, u8)

A value was found in the trie with a nibble key that was not byte-aligned. The first parameter is the byte-aligned part of the prefix and the second parameter is the remaining nibble.

DecoderError(T, E)

Corrupt Trie item

InvalidHash(T, Vec<u8>)