Enum trie_db::TrieKinds [−][src]
pub enum TrieKinds<'db, L: TrieLayout> {
Generic(TrieDB<'db, L>),
Secure(SecTrieDB<'db, L>),
Fat(FatDB<'db, L>),
}Expand description
All different kinds of tries. This is used to prevent a heap allocation for every created trie.
Variants
Generic(TrieDB<'db, L>)A generic trie db.
Tuple Fields of Generic
0: TrieDB<'db, L>Secure(SecTrieDB<'db, L>)A secure trie db.
Tuple Fields of Secure
0: SecTrieDB<'db, L>Fat(FatDB<'db, L>)A fat trie db.
Tuple Fields of Fat
0: FatDB<'db, L>Trait Implementations
Does the trie contain a given key?
Search for the key with the given query parameter. See the docs of the Query
trait for more details. Read more
Returns a depth-first iterator over the elements of trie.