Enum trie_db::node::Node[][src]

pub enum Node<'a> {
    Empty,
    Leaf(NibbleSlice<'a>, &'a [u8]),
    Extension(NibbleSlice<'a>, NodeHandle<'a>),
    Branch([Option<NodeHandle<'a>>; 16]Option<&'a [u8]>),
    NibbledBranch(NibbleSlice<'a>, [Option<NodeHandle<'a>>; 16]Option<&'a [u8]>),
}
Type of node in the trie and essential information thereof.

Variants

Empty

Null trie node; could be an empty root or an empty branch entry.

Leaf(NibbleSlice<'a>, &'a [u8])

Leaf node; has key slice and value. Value may not be empty.

Extension(NibbleSlice<'a>, NodeHandle<'a>)

Extension node; has key slice and node data. Data may not be null.

Branch node; has slice of child nodes (each possibly null) and an optional immediate node data.

NibbledBranch(NibbleSlice<'a>, [Option<NodeHandle<'a>>; 16]Option<&'a [u8]>)

Branch node with support for a nibble (when extension nodes are not used).