Enum trie_db::node::NodeHandlePlan[][src]

pub enum NodeHandlePlan {
    Hash(Range<usize>),
    Inline(Range<usize>),
}
A NodeHandlePlan is a decoding plan for constructing a NodeHandle from an encoded trie node. This is used as a substructure of NodePlan. See NodePlan for details.

Variants

Hash(Range<usize>)
Inline(Range<usize>)

Implementations

impl NodeHandlePlan[src]

pub fn build<'a, 'b>(&'a self, data: &'b [u8]) -> NodeHandle<'b>[src]

Build a node handle by decoding a byte slice according to the node handle plan. It is the responsibility of the caller to ensure that the node plan was created for the argument data, otherwise the call may decode incorrectly or panic.