Struct trie_db::node::NibbleSlicePlan[][src]

pub struct NibbleSlicePlan { /* fields omitted */ }
A NibbleSlicePlan is a blueprint for decoding a nibble slice from a byte slice. The NibbleSlicePlan is created by parsing a byte slice and can be reused multiple times.

Implementations

impl NibbleSlicePlan[src]

pub fn new(bytes: Range<usize>, offset: usize) -> Self[src]

Construct a nibble slice decode plan.

pub fn len(&self) -> usize[src]

Returns the nibble length of the slice.

pub fn build<'a, 'b>(&'a self, data: &'b [u8]) -> NibbleSlice<'b>[src]

Build a nibble slice by decoding a byte slice according to the plan. It is the responsibility of the caller to ensure that the node plan was created for the argument data, otherwise the call may decode incorrectly or panic.