Struct trie_db::node::OwnedNode [−][src]
An OwnedNode is an owned type from which a Node can be constructed which borrows data from
the OwnedNode. This is useful for trie iterators.
Implementations
Construct an OwnedNode by decoding an owned data source according to some codec.
Returns a reference to the backing data.