Struct trie_db::FatDBMut[][src]

pub struct FatDBMut<'db, L> where
    L: TrieLayout
{ /* fields omitted */ }
A mutable Trie implementation which hashes keys and uses a generic HashDB backing database. Additionaly it stores inserted hash-key mappings for later retrieval.

Use it as a Trie or TrieMut trait object.

Implementations

impl<'db, L> FatDBMut<'db, L> where
    L: TrieLayout
[src]

pub fn new(
    db: &'db mut dyn HashDB<L::Hash, DBValue>,
    root: &'db mut TrieHash<L>
) -> Self
[src]

Create a new trie with the backing database db and empty root Initialise to the state entailed by the genesis block. This guarantees the trie is built correctly.

pub fn from_existing(
    db: &'db mut dyn HashDB<L::Hash, DBValue>,
    root: &'db mut TrieHash<L>
) -> Result<Self, TrieHash<L>, CError<L>>
[src]

Create a new trie with the backing database db and root.

Returns an error if root does not exist.

pub fn db(&self) -> &dyn HashDB<L::Hash, DBValue>[src]

Get the backing database.

pub fn db_mut(&mut self) -> &mut dyn HashDB<L::Hash, DBValue>[src]

Get the backing database.