NibbleVec

Struct NibbleVec 

pub struct NibbleVec { /* private fields */ }
Owning, nibble-oriented byte vector. Counterpart to NibbleSlice. Nibbles are always left aligned, so making a NibbleVec from a NibbleSlice can get costy.

Implementations

Source

impl NibbleVec

pub fn new() -> Self

Make a new NibbleVec.

pub fn len(&self) -> usize

Length of the NibbleVec.

pub fn is_empty(&self) -> bool

Returns true if NibbleVec has zero length.

pub fn at(&self, idx: usize) -> u8

Try to get the nibble at the given offset.

pub fn push(&mut self, nibble: u8)

Push a nibble onto the NibbleVec. Ignores the high 4 bits.

pub fn pop(&mut self) -> Option<u8>

Try to pop a nibble off the NibbleVec. Fails if len == 0.

pub fn drop_lasts(&mut self, n: usize)

Remove then n last nibbles in a faster way than popping n times.

pub fn as_prefix(&self) -> Prefix<'_>

Get Prefix representation of this NibbleVec.

pub fn append(&mut self, v: &NibbleVec)

Append another NibbleVec. Can be slow (alignement of second vec).

pub fn append_partial(&mut self, (start_byte, sl): Partial<'_>)

Append a Partial. Can be slow (alignement of partial).

pub fn inner(&self) -> &[u8]

Get the underlying byte slice.

pub fn clear(&mut self)

clear

pub fn as_nibbleslice(&self) -> Option<NibbleSlice<'_>>

Try to treat this NibbleVec as a NibbleSlice. Works only if there is no padding.

pub fn starts_with(&self, other: &Self) -> bool

Do we start with the same nibbles as the whole of them?

pub fn starts_with_slice(&self, other: &NibbleSlice<'_>) -> bool

Same as Self::starts_with but using NibbleSlice.

pub fn right_iter<'a>(&'a self) -> impl Iterator<Item = u8> + 'a

Return an iterator over Partial bytes representation.