Enum trie_db::node::NodeHandlePlan [−][src]
A NodeHandlePlan is a decoding plan for constructing a NodeHandle from an encoded trie
node. This is used as a substructure of NodePlan. See NodePlan for details.
Variants
Implementations
impl NodeHandlePlan[src]
impl NodeHandlePlan[src]pub fn build<'a, 'b>(&'a self, data: &'b [u8]) -> NodeHandle<'b>[src]
pub fn build<'a, 'b>(&'a self, data: &'b [u8]) -> NodeHandle<'b>[src]Build a node handle by decoding a byte slice according to the node handle plan. It is the responsibility of the caller to ensure that the node plan was created for the argument data, otherwise the call may decode incorrectly or panic.