Enum trie_db::node::NodePlan[][src]

pub enum NodePlan {
    Empty,
    Leaf {
        partial: NibbleSlicePlan,
        value: Range<usize>,
    },
    Extension {
        partial: NibbleSlicePlan,
        child: NodeHandlePlan,
    },
    Branch {
        value: Option<Range<usize>>,
        children: [Option<NodeHandlePlan>; 16],
    },
    NibbledBranch {
        partial: NibbleSlicePlan,
        value: Option<Range<usize>>,
        children: [Option<NodeHandlePlan>; 16],
    },
}
A NodePlan is a blueprint for decoding a node from a byte slice. The NodePlan is created by parsing an encoded node and can be reused multiple times. This is useful as a Node borrows from a byte slice and this struct does not.

The enum values mirror those of Node except that instead of byte slices, this struct stores ranges that can be used to index into a large byte slice.

Variants

Empty

Null trie node; could be an empty root or an empty branch entry.

Leaf

Leaf node; has a partial key plan and value.

Show fields

Fields of Leaf

partial: NibbleSlicePlanvalue: Range<usize>
Extension

Extension node; has a partial key plan and child data.

Show fields

Fields of Extension

partial: NibbleSlicePlanchild: NodeHandlePlan
Branch

Branch node; has slice of child nodes (each possibly null) and an optional immediate node data.

Show fields

Fields of Branch

value: Option<Range<usize>>children: [Option<NodeHandlePlan>; 16]
NibbledBranch

Branch node with support for a nibble (when extension nodes are not used).

Show fields

Fields of NibbledBranch

partial: NibbleSlicePlanvalue: Option<Range<usize>>children: [Option<NodeHandlePlan>; 16]

Implementations

impl NodePlan[src]

pub fn build<'a, 'b>(&'a self, data: &'b [u8]) -> Node<'b>[src]

Build a node by decoding a byte slice according to the node plan. It is the responsibility of the caller to ensure that the node plan was created for the argument data, otherwise the call may decode incorrectly or panic.