Struct trie_db::FatDB[][src]

pub struct FatDB<'db, L> where
    L: TrieLayout
{ /* fields omitted */ }
A Trie implementation which hashes keys and uses a generic HashDB backing database. Additionaly it stores inserted hash-key mappings for later retrieval.

Use it as a Trie or TrieMut trait object.

Implementations

impl<'db, L> FatDB<'db, L> where
    L: TrieLayout
[src]

pub fn new(
    db: &'db dyn HashDBRef<L::Hash, DBValue>,
    root: &'db TrieHash<L>
) -> Result<Self, TrieHash<L>, CError<L>>
[src]

Create a new trie with the backing database db and empty root Initialise to the state entailed by the genesis block. This guarantees the trie is built correctly.

pub fn db(&self) -> &dyn HashDBRef<L::Hash, DBValue>[src]

Get the backing database.