Struct trie_db::FatDB [−][src]
pub struct FatDB<'db, L> where
L: TrieLayout, { /* fields omitted */ }Expand description
A Trie implementation which hashes keys and uses a generic HashDB backing database.
Additionaly it stores inserted hash-key mappings for later retrieval.
Use it as a Trie or TrieMut trait object.
Implementations
impl<'db, L> FatDB<'db, L> where
L: TrieLayout, [src]
impl<'db, L> FatDB<'db, L> where
L: TrieLayout, [src]Trait Implementations
impl<'db, L> Trie<L> for FatDB<'db, L> where
L: TrieLayout, [src]
impl<'db, L> Trie<L> for FatDB<'db, L> where
L: TrieLayout, [src]fn contains(&self, key: &[u8]) -> Result<bool, TrieHash<L>, CError<L>>[src]
fn contains(&self, key: &[u8]) -> Result<bool, TrieHash<L>, CError<L>>[src]Does the trie contain a given key?
fn get_with<'a, 'key, Q: Query<L::Hash>>(
&'a self,
key: &'key [u8],
query: Q
) -> Result<Option<Q::Item>, TrieHash<L>, CError<L>> where
'a: 'key, [src]
fn get_with<'a, 'key, Q: Query<L::Hash>>(
&'a self,
key: &'key [u8],
query: Q
) -> Result<Option<Q::Item>, TrieHash<L>, CError<L>> where
'a: 'key, [src]Search for the key with the given query parameter. See the docs of the Query
trait for more details. Read more