Struct trie_db::FatDBMut [−][src]
pub struct FatDBMut<'db, L> where
L: TrieLayout, { /* fields omitted */ }Expand description
A mutable Trie implementation which hashes keys and uses a generic HashDB backing database.
Additionaly it stores inserted hash-key mappings for later retrieval.
Use it as a Trie or TrieMut trait object.
Implementations
impl<'db, L> FatDBMut<'db, L> where
L: TrieLayout, [src]
impl<'db, L> FatDBMut<'db, L> where
L: TrieLayout, [src]pub fn new(
db: &'db mut dyn HashDB<L::Hash, DBValue>,
root: &'db mut TrieHash<L>
) -> Self[src]
pub fn new(
db: &'db mut dyn HashDB<L::Hash, DBValue>,
root: &'db mut TrieHash<L>
) -> Self[src]Create a new trie with the backing database db and empty root
Initialise to the state entailed by the genesis block.
This guarantees the trie is built correctly.