Struct trie_db::NibbleVec [−][src]
pub struct NibbleVec { /* fields omitted */ }Expand description
Owning, nibble-oriented byte vector. Counterpart to NibbleSlice.
Nibbles are always left aligned, so making a NibbleVec from
a NibbleSlice can get costy.
Implementations
impl NibbleVec[src]
impl NibbleVec[src]pub fn drop_lasts(&mut self, n: usize)[src]
pub fn drop_lasts(&mut self, n: usize)[src]Remove then n last nibbles in a faster way than popping n times.
pub fn append(&mut self, v: &NibbleVec)[src]
pub fn append(&mut self, v: &NibbleVec)[src]Append another NibbleVec. Can be slow (alignement of second vec).
pub fn append_partial(&mut self, (start_byte, sl): Partial<'_>)[src]
pub fn append_partial(&mut self, (start_byte, sl): Partial<'_>)[src]Append a Partial. Can be slow (alignement of partial).
pub fn as_nibbleslice(&self) -> Option<NibbleSlice<'_>>[src]
pub fn as_nibbleslice(&self) -> Option<NibbleSlice<'_>>[src]Try to treat this NibbleVec as a NibbleSlice. Works only if there is no padding.
pub fn starts_with(&self, other: &Self) -> bool[src]
pub fn starts_with(&self, other: &Self) -> bool[src]Do we start with the same nibbles as the whole of them?