Trait trie_db::HashDB[][src]

pub trait HashDB<H, T>: Send + Sync + AsHashDB<H, T> where
    H: Hasher
{ fn get(
        &self,
        key: &<H as Hasher>::Out,
        prefix: (&[u8], Option<u8>)
    ) -> Option<T>;
fn contains(
        &self,
        key: &<H as Hasher>::Out,
        prefix: (&[u8], Option<u8>)
    ) -> bool;
fn insert(
        &mut self,
        prefix: (&[u8], Option<u8>),
        value: &[u8]
    ) -> <H as Hasher>::Out;
fn emplace(
        &mut self,
        key: <H as Hasher>::Out,
        prefix: (&[u8], Option<u8>),
        value: T
    );
fn remove(&mut self, key: &<H as Hasher>::Out, prefix: (&[u8], Option<u8>)); }
Trait modelling datastore keyed by a hash defined by the Hasher.

Required methods

fn get(
    &self,
    key: &<H as Hasher>::Out,
    prefix: (&[u8], Option<u8>)
) -> Option<T>
[src]

Look up a given hash into the bytes that hash to it, returning None if the hash is not known.

fn contains(
    &self,
    key: &<H as Hasher>::Out,
    prefix: (&[u8], Option<u8>)
) -> bool
[src]

Check for the existance of a hash-key.

fn insert(
    &mut self,
    prefix: (&[u8], Option<u8>),
    value: &[u8]
) -> <H as Hasher>::Out
[src]

Insert a datum item into the DB and return the datum’s hash for a later lookup. Insertions are counted and the equivalent number of remove()s must be performed before the data is considered dead.

fn emplace(
    &mut self,
    key: <H as Hasher>::Out,
    prefix: (&[u8], Option<u8>),
    value: T
)
[src]

Like insert(), except you provide the key and the data is all moved.

fn remove(&mut self, key: &<H as Hasher>::Out, prefix: (&[u8], Option<u8>))[src]

Remove a datum previously inserted. Insertions can be “owed” such that the same number of insert()s may happen without the data being eventually being inserted into the DB. It can be “owed” more than once.