Trait trie_db::NodeCodec [−][src]
pub trait NodeCodec: Sized { type Error: Error; type HashOut: AsRef<[u8]> + AsMut<[u8]> + Default + MaybeDebug + PartialEq + Eq + Hash + Send + Sync + Clone + Copy; fn hashed_null_node() -> Self::HashOut; fn decode_plan(data: &[u8]) -> Result<NodePlan, Self::Error>; fn is_empty_node(data: &[u8]) -> bool; fn empty_node() -> &'static [u8]ⓘ; fn leaf_node(partial: Partial<'_>, value: &[u8]) -> Vec<u8>ⓘ; fn extension_node(
partial: impl Iterator<Item = u8>,
number_nibble: usize,
child_ref: ChildReference<Self::HashOut>
) -> Vec<u8>ⓘ; fn branch_node(
children: impl Iterator<Item = impl Borrow<Option<ChildReference<Self::HashOut>>>>,
value: Option<&[u8]>
) -> Vec<u8>ⓘ; fn branch_node_nibbled(
partial: impl Iterator<Item = u8>,
number_nibble: usize,
children: impl Iterator<Item = impl Borrow<Option<ChildReference<Self::HashOut>>>>,
value: Option<&[u8]>
) -> Vec<u8>ⓘ; fn decode(data: &[u8]) -> Result<Node<'_>, Self::Error> { ... } }
Trait for trie node encoding/decoding.
Associated Types
Required methods
fn hashed_null_node() -> Self::HashOut[src]
fn hashed_null_node() -> Self::HashOut[src]Get the hashed null node.
fn decode_plan(data: &[u8]) -> Result<NodePlan, Self::Error>[src]
fn decode_plan(data: &[u8]) -> Result<NodePlan, Self::Error>[src]Decode bytes to a NodePlan. Returns Self::E on failure.
fn is_empty_node(data: &[u8]) -> bool[src]
fn is_empty_node(data: &[u8]) -> bool[src]Check if the provided bytes correspond to the codecs “empty” node.
fn empty_node() -> &'static [u8]ⓘ[src]
fn empty_node() -> &'static [u8]ⓘ[src]Returns an encoded empty node.
fn leaf_node(partial: Partial<'_>, value: &[u8]) -> Vec<u8>ⓘ[src]
fn leaf_node(partial: Partial<'_>, value: &[u8]) -> Vec<u8>ⓘ[src]Returns an encoded leaf node
fn extension_node(
partial: impl Iterator<Item = u8>,
number_nibble: usize,
child_ref: ChildReference<Self::HashOut>
) -> Vec<u8>ⓘ[src]
fn extension_node(
partial: impl Iterator<Item = u8>,
number_nibble: usize,
child_ref: ChildReference<Self::HashOut>
) -> Vec<u8>ⓘ[src]Returns an encoded extension node
Note that number_nibble is the number of element of the iterator
it can possibly be obtain by Iterator size_hint, but
for simplicity it is used directly as a parameter.
fn branch_node(
children: impl Iterator<Item = impl Borrow<Option<ChildReference<Self::HashOut>>>>,
value: Option<&[u8]>
) -> Vec<u8>ⓘ[src]
fn branch_node(
children: impl Iterator<Item = impl Borrow<Option<ChildReference<Self::HashOut>>>>,
value: Option<&[u8]>
) -> Vec<u8>ⓘ[src]Returns an encoded branch node.
Takes an iterator yielding ChildReference<Self::HashOut> and an optional value.
fn branch_node_nibbled(
partial: impl Iterator<Item = u8>,
number_nibble: usize,
children: impl Iterator<Item = impl Borrow<Option<ChildReference<Self::HashOut>>>>,
value: Option<&[u8]>
) -> Vec<u8>ⓘ[src]
fn branch_node_nibbled(
partial: impl Iterator<Item = u8>,
number_nibble: usize,
children: impl Iterator<Item = impl Borrow<Option<ChildReference<Self::HashOut>>>>,
value: Option<&[u8]>
) -> Vec<u8>ⓘ[src]Returns an encoded branch node with a possible partial path.
number_nibble is the partial path length as in extension_node.